@@ -1,6 +1,6 @@
 use std::fmt::{Display, Formatter};
 
-#[derive(Debug)]
+#[derive(Debug, PartialEq, Eq)]
 pub enum FrameError {
     IllegalFin,
 
@@ -8,9 +8,13 @@ pub enum FrameError {
 
     IllegalOpCode,
 
+    IllegalData,
+
     NotEnoughData,
 
     NotEnoughCapacity,
+
+    UnsupportedOpcode,
 }
 
 impl Display for FrameError {
@@ -20,8 +24,13 @@ impl Display for FrameError {
             IllegalFin => write!(f, "Illegal fin value"),
             IllegalMask => write!(f, "Illegal mask value"),
             IllegalOpCode => write!(f, "Illegal opcode value"),
+            IllegalData => write!(f, "Illegal data"),
             NotEnoughData => write!(f, "Not enough data to parse"),
             NotEnoughCapacity => write!(f, "Not enough space to write to"),
+            UnsupportedOpcode => write!(
+                f,
+                "Unsupported opcode, only support binary, ping, pong, close"
+            ),
         }
     }
 }
